Skip to contents

Returns a 2x3 affine transformation matrix that applies a simultaneous horizontal shear (controlled by sx) and vertical shear (controlled by sy). sx shifts columns in the x direction proportionally to their y position; sy shifts rows in the y direction proportionally to their x position. Use zero for either to apply a single-axis shear.

Usage

affine_shear(sx, sy)

Arguments

sx

Numeric. Horizontal shear factor.

sy

Numeric. Vertical shear factor.

Value

A 2x3 numeric matrix.